@@ -12,10 +12,10 @@ Asynchronous spotify api wrapper
 
 __title__ = 'async_spotify'
 __author__ = 'HuiiBuh'
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 __license__ = 'MIT'
 
-from .api.preferences import Preferences
+from .api.spotify_api_preferences import SpotifyApiPreferences
 from .api.spotify_api_client import SpotifyApiClient
 from .authentification.spotify_authorization_token import SpotifyAuthorisationToken
 from .authentification.spotify_cookies import SpotifyCookie
